@@ -23,13 +23,17 @@ static int pid_wait(lua_State *L) {
 }
 #endif
 
-static const luaL_reg native_lib_f[] = {
+static const luaL_Reg native_lib_f[] = {
   {"pid_wait", pid_wait},
   {NULL, NULL}
 };
 
 int luaopen_nvim_native(lua_State *L) {
   lua_newtable(L);
+#if LUA_VERSION_NUM >= 502
+  luaL_setfuncs(L, native_lib_f, NULL);
+#else
   luaL_register(L, NULL, native_lib_f);
+#endif
   return 1;
 }
